## Future worls: 

## 初期濃度を変化させる事例  
https://doi.org/10.1002/ange.201609757  
https://doi.org/10.1039/C8SC04698K  
https://doi.org/10.1039/D4DD00111G  

## 重合反応  
https://doi.org/10.1295/koron.61.394  
https://doi.org/10.1021/ja01267a030  
https://doi.org/10.1039/D6PY00103C  

Shi, J.; He, J.; Yao, Q.; Li, R.; Liu, D.; Liang, X.; Wang, L. Polymerization Reaction Kinetics of Poly α-Olefin and Numerical Simulation of a Continuous Polymerization Reactor. Processes 2025, 13, 3375. https://doi.org/10.3390/pr13113375

**References**  
6. Paul J. Flory, Kinetics of Polyesterification: A Study of the Effects of Molecular Weight and Viscosity on Reaction Rate, Journal of the American Chemical Society 1939 61 (12), 3334-3340, DOI: 10.1021/ja01267a030  
https://doi.org/10.1021/ja01267a030


- **torchdiffeq**: Chen, R. T. Q. (2021). torchdiffeq (Version 0.2.2) [Computer software]. https://github.com/rtqichen/torchdiffeq  
